@@ -107,6 +107,7 @@ from synctera_client.apis.paths.spend_controls import SpendControls
 from synctera_client.apis.paths.spend_controls_spend_control_id import SpendControlsSpendControlId
 from synctera_client.apis.paths.statements import Statements
 from synctera_client.apis.paths.statements_statement_id import StatementsStatementId
+from synctera_client.apis.paths.statements_statement_id_transactions import StatementsStatementIdTransactions
 from synctera_client.apis.paths.transactions_internal_transfer import TransactionsInternalTransfer
 from synctera_client.apis.paths.transactions_internal_transfer_id import TransactionsInternalTransferId
 from synctera_client.apis.paths.transactions_pending import TransactionsPending
@@ -237,6 +238,7 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.SPEND_CONTROLS_SPEND_CONTROL_ID: SpendControlsSpendControlId,
         PathValues.STATEMENTS: Statements,
         PathValues.STATEMENTS_STATEMENT_ID: StatementsStatementId,
+        PathValues.STATEMENTS_STATEMENT_ID_TRANSACTIONS: StatementsStatementIdTransactions,
         PathValues.TRANSACTIONS_INTERNAL_TRANSFER: TransactionsInternalTransfer,
         PathValues.TRANSACTIONS_INTERNAL_TRANSFER_ID: TransactionsInternalTransferId,
         PathValues.TRANSACTIONS_PENDING: TransactionsPending,
@@ -368,6 +370,7 @@ path_to_api = PathToApi(
         PathValues.SPEND_CONTROLS_SPEND_CONTROL_ID: SpendControlsSpendControlId,
         PathValues.STATEMENTS: Statements,
         PathValues.STATEMENTS_STATEMENT_ID: StatementsStatementId,
+        PathValues.STATEMENTS_STATEMENT_ID_TRANSACTIONS: StatementsStatementIdTransactions,
         PathValues.TRANSACTIONS_INTERNAL_TRANSFER: TransactionsInternalTransfer,
         PathValues.TRANSACTIONS_INTERNAL_TRANSFER_ID: TransactionsInternalTransferId,
         PathValues.TRANSACTIONS_PENDING: TransactionsPending,
